@@ -3,6 +3,7 @@ from datetime import timedelta
 from unittest.mock import patch
 
 import dhooks_lite
+import requests_mock
 from bs4 import BeautifulSoup
 from markdown import markdown
 from requests.exceptions import HTTPError
@@ -267,75 +268,6 @@ class TestSaveMethod(LoadTestDataMixin, NoSocketsTestCase):
         self.assertFalse(tracker.color)
 
 
-@patch(MODULE_PATH + ".dhooks_lite.Webhook.execute")
-class TestWebhookSendMessage(LoadTestDataMixin, TestCase):
-    def setUp(self) -> None:
-        self.message = Webhook._discord_message_asjson(content="Test message")
-        cache.delete(self.webhook_1._blocked_cache_key())
-
-    def test_when_send_ok_returns_true(self, mock_execute):
-        mock_execute.return_value = dhooks_lite.WebhookResponse(dict(), status_code=200)
-
-        response = self.webhook_1.send_message_to_webhook(self.message)
-
-        self.assertTrue(response.status_ok)
-        self.assertTrue(mock_execute.called)
-
-    def test_when_send_not_ok_returns_false(self, mock_execute):
-        mock_execute.return_value = dhooks_lite.WebhookResponse(dict(), status_code=404)
-
-        response = self.webhook_1.send_message_to_webhook(self.message)
-
-        self.assertFalse(response.status_ok)
-        self.assertTrue(mock_execute.called)
-
-    def test_too_many_requests_1(self, mock_execute):
-        """when 429 received, then set blocker and raise exception"""
-        mock_execute.return_value = dhooks_lite.WebhookResponse(
-            headers={"x-ratelimit-remaining": "5", "x-ratelimit-reset-after": "60"},
-            status_code=429,
-            content={
-                "global": False,
-                "message": "You are being rate limited.",
-                "retry_after": 2000,
-            },
-        )
-
-        try:
-            self.webhook_1.send_message_to_webhook(self.message)
-        except Exception as ex:
-            self.assertIsInstance(ex, WebhookTooManyRequests)
-            self.assertEqual(ex.retry_after, 2002)
-        else:
-            self.fail("Did not raise excepted exception")
-
-        self.assertTrue(mock_execute.called)
-        self.assertAlmostEqual(
-            cache.ttl(self.webhook_1._blocked_cache_key()), 2002, delta=5
-        )
-
-    def test_too_many_requests_2(self, mock_execute):
-        """when 429 received and no retry value in response, then use default"""
-        mock_execute.return_value = dhooks_lite.WebhookResponse(
-            headers={"x-ratelimit-remaining": "5", "x-ratelimit-reset-after": "60"},
-            status_code=429,
-            content={
-                "global": False,
-                "message": "You are being rate limited.",
-            },
-        )
-
-        try:
-            self.webhook_1.send_message_to_webhook(self.message)
-        except Exception as ex:
-            self.assertIsInstance(ex, WebhookTooManyRequests)
-            self.assertEqual(ex.retry_after, 600)
-        else:
-            self.fail("Did not raise excepted exception")
-
-        self.assertTrue(mock_execute.called)
-
-
 if "discord" in app_labels():
 
     @patch(MODULE_PATH + ".DiscordUser", spec=True)
@@ -423,6 +355,102 @@ if "discord" in app_labels():
             self.assertNotIn(f"<@&{self.group_1.pk}>", message["content"])
 
 
+@requests_mock.Mocker()
+class TestWebhookSendMessage(LoadTestDataMixin, TestCase):
+    def setUp(self) -> None:
+        self.message = Webhook._discord_message_asjson(content="Test message")
+        cache.clear()
+
+    def test_when_send_ok_returns_true(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "POST",
+            self.webhook_1.url,
+            status_code=200,
+            json={
+                "name": "test webhook",
+                "type": 1,
+                "channel_id": "199737254929760256",
+                "token": "3d89bb7572e0fb30d8128367b3b1b44fecd1726de135cbe28a41f8b2f777c372ba2939e72279b94526ff5d1bd4358d65cf11",
+                "avatar": None,
+                "guild_id": "199737254929760256",
+                "id": "223704706495545344",
+                "application_id": None,
+                "user": {
+                    "username": "test",
+                    "discriminator": "7479",
+                    "id": "190320984123768832",
+                    "avatar": "b004ec1740a63ca06ae2e14c5cee11f3",
+                    "public_flags": 131328,
+                },
+            },
+        )
+        # when
+        response = self.webhook_1.send_message_to_webhook(self.message)
+        # then
+        self.assertTrue(response.status_ok)
+        self.assertTrue(requests_mocker.called)
+
+    def test_when_send_not_ok_returns_false(self, requests_mocker):
+        # given
+        requests_mocker.register_uri("POST", self.webhook_1.url, status_code=404)
+        # when
+        response = self.webhook_1.send_message_to_webhook(self.message)
+        # then
+        self.assertFalse(response.status_ok)
+        self.assertTrue(requests_mocker.called)
+
+    def test_too_many_requests_normal(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "POST",
+            self.webhook_1.url,
+            status_code=429,
+            json={
+                "global": False,
+                "message": "You are being rate limited.",
+                "retry_after": 2000,
+            },
+            headers={
+                "x-ratelimit-remaining": "5",
+                "x-ratelimit-reset-after": "60",
+                "Retry-After": "2000",
+            },
+        )
+        # when/then
+        try:
+            self.webhook_1.send_message_to_webhook(self.message)
+        except Exception as ex:
+            self.assertIsInstance(ex, WebhookTooManyRequests)
+            self.assertEqual(ex.retry_after, 2002)
+        else:
+            self.fail("Did not raise excepted exception")
+
+        self.assertAlmostEqual(
+            cache.ttl(self.webhook_1._blocked_cache_key()), 2002, delta=5
+        )
+
+    def test_too_many_requests_no_retry_value(self, requests_mocker):
+        # given
+        requests_mocker.register_uri(
+            "POST",
+            self.webhook_1.url,
+            status_code=429,
+            headers={
+                "x-ratelimit-remaining": "5",
+                "x-ratelimit-reset-after": "60",
+            },
+        )
+        # when/then
+        try:
+            self.webhook_1.send_message_to_webhook(self.message)
+        except Exception as ex:
+            self.assertIsInstance(ex, WebhookTooManyRequests)
+            self.assertEqual(ex.retry_after, WebhookTooManyRequests.DEFAULT_RESET_AFTER)
+        else:
+            self.fail("Did not raise excepted exception")
+
+
 class TestEveKillmail(LoadTestDataMixin, NoSocketsTestCase):
     @classmethod
     def setUpClass(cls):
